@@ -20,6 +20,7 @@ class BitwiseDays:
     (32, "F","Friday"),
     (64, "Sa","Saturday"),
   )
+
   SUNDAY,MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY,SATURDAY = [2**i for i in range(0,7)]
   WEEKDAYS = 2**6 - 2
   WEEKENDS = SUNDAY + SATURDAY
@@ -30,11 +31,13 @@ class BitwiseDays:
     self.raw_value = raw_value
 
   def __unicode__(self):
+    raw_value = self.raw_value
+    
     if self.raw_value == BitwiseDays.WEEKENDS:
       return "weekends"
     elif self.raw_value == BitwiseDays.WEEKDAYS:
       return "weekdays"
-    elif self.raw_value == 0 or self.raw_value == 2**7 - 1:
+    elif self.raw_value == 0 or self.raw_value == 2**7 - 1 or self.raw_value == None:
       return "" 
     else:
       days = []
@@ -56,4 +59,7 @@ class BitwiseDays:
   def included(self,raw_value):
     return self.raw_value & raw_value
 
+  def iso_included(self,iso_value):
+    return self.raw_value & 2**(iso_value % 7)
+
 BITWISE_DAY_CHOICES = BitwiseDays.CHOICES
